# Changelog

## [Unreleased][]

[Unreleased]: https://github.com/k6io/chaostoolkit-k6/compare/0.3.0...HEAD

## [0.3.0][] - 2021-04-23

[0.3.0]: https://github.com/k6io/chaostoolkit-k6/tree/0.3.0

### Changed

-   Format code according to pep8

## [0.2.0][] - 2021-01-25

[0.2.0]: https://github.com/k6io/chaostoolkit-k6/tree/0.2.0

### Added

-   Initial release
